@@ -1,7 +1,7 @@
 # awl.rankedmodel.admin.py
 
 from django.contrib.contenttypes.models import ContentType
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 
 # =============================================================================
 # RankedModel Helper Methods
